<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml" version="1.0">

<xsl:strip-space elements="doc chapter section"/>
<xsl:output method="xml" indent="yes" encoding="iso-8859-1"
            doctype-system="http://www.w3.org/2002/04/xhtml-math-svg/xhtml-math-svg.dtd"
            doctype-public="-//W3C//DTD XHTML 1.1 plus MathML 2.0 plus SVG 1.1//EN"/>

<xsl:template match="doc">
<xsl:element name="html" namespace="http://www.w3.org/1999/xhtml">
<head>
   <meta charset="utf-8"/>
   <link>
   <xsl:attribute name="rel">stylesheet</xsl:attribute>
   <xsl:attribute name="type">text/css</xsl:attribute>
   <xsl:attribute name="href"><xsl:value-of select="@style"/></xsl:attribute>
   </link>
   <title>
      <xsl:if test='not(*/titlepage/title)'>
      -
      </xsl:if>
      <xsl:value-of select="*/titlepage/title"/>
   </title>
   <style type="text/css">
      .center
      {
         text-align : center ;
      }
      table.docinfo
      {
         margin-left  : 10% ;
         margin-right : 10% ;
         border-style : solid ;
      }
      th
      {
         border-style : solid ;
         border-width : thin ;
      }
      h3.toc
      {
         margin-left : 2em ;
      }
      pre.example
      {
         border : solid ;
         padding-bottom : 1em ;
      }
      span.red
      {
         color : red ;
      }
      span.green
      {
         color : green ;
      }
      span.blue
      {
         color : blue ;
      }
      span.cyan
      {
         color : cyan ;
      }
      span.magenta
      {
         color : magenta ;
      }
      span.yellow
      {
         color : yellow ;
      }
      span.orange
      {
         color : orange ;
      }
      span.violet
      {
         color : violet ;
      }
      span.purple
      {
         color : purple ;
      }
      span.brown
      {
         color : brown ;
      }
      span.pink
      {
         color : pink ;
      }
      span.olive
      {
         color : olive ;
      }
      span.black
      {
         color : black ;
      }
      span.darkgray
      {
         color : darkgray ;
      }
      span.gray
      {
         color : gray ;
      }
      span.lightgray
      {
         color : lightgray ;
      }
      span.white
      {
         color : white ;
      }
   </style>
</head>

<body>
   <xsl:apply-templates/>
   <hr/>
   <xsl:apply-templates select="//footnote" mode="footnotes"/>
</body>
</xsl:element>
</xsl:template>

<xsl:template match="titlepage">
   <div>
   <xsl:attribute name="class">titlepage</xsl:attribute>
   <xsl:apply-templates/>
   </div>
</xsl:template>

<xsl:template match="title">
   <h1>
   <xsl:attribute name="class">titlepage</xsl:attribute>
   <xsl:apply-templates/>
   </h1>
</xsl:template>

<xsl:template match="subtitle">
   <h2>
   <xsl:attribute name="class">titlepage</xsl:attribute>
   <xsl:apply-templates/>
   </h2>
</xsl:template>

<xsl:template match="author">
   <xsl:apply-templates/><br/>
</xsl:template>

<xsl:template match="date">
   <p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="docinfo">
   <table class="docinfo">
   <tr><th colspan="2">Document Information</th></tr>
   <xsl:apply-templates/>
   </table>
</xsl:template>

<xsl:template match="infoitem">
   <tr>
     <td><xsl:value-of select="@label"/></td>
     <td><xsl:apply-templates/></td>
   </tr>
</xsl:template>

<xsl:template match="abstract">
   <blockquote>
   <p><b>Abstract:</b></p>
   <p>
   <xsl:apply-templates/>
   </p>
   </blockquote>
</xsl:template>

<!--  A template to create the section number for a node -->

<xsl:template name="section-number" mode="section-number" match="node()">
   <xsl:number count="chapter|section" level="multiple" format="1.1 "/>
</xsl:template>

<!--  Create a table of contents -->

<xsl:template match="toc">
<h1>Table Of Contents</h1>
<xsl:for-each select="../chapter">
   <h2>
   <xsl:number count="chapter"/>
   <xsl:text>  </xsl:text>
   <a>
   <xsl:attribute name="href">#CH<xsl:number count="chapter"/></xsl:attribute>
   <xsl:value-of select="heading"/>
   </a>
   </h2>
   <xsl:for-each select="section">
      <h3 class="toc">
      <xsl:number count="chapter|section" level="multiple" format="1.1 "/>
      <a>
      <xsl:attribute name="href">#SEC<xsl:number count="chapter|section" level="multiple" format="1.1"/></xsl:attribute>
      <xsl:value-of select="heading"/>
      </a>
      </h3>
   </xsl:for-each>
</xsl:for-each>
<hr></hr>
</xsl:template>

<!--  Chapter and section headings are all automatically numbered -->

<xsl:template match="chapter/heading">
   <h1>
     <xsl:number count="chapter"/>
     <xsl:text>  </xsl:text>
      <a>
      <xsl:attribute name="id">CH<xsl:number count="chapter"/></xsl:attribute>
      </a>
     <xsl:apply-templates/>
   </h1>
</xsl:template>

<xsl:template match="section/heading">
   <h2>
     <xsl:number count="chapter|section" level="multiple" format="1.1 "/>
     <a>
     <xsl:attribute name="id">SEC<xsl:number count="chapter|section" level="multiple" format="1.1"/></xsl:attribute>
     </a>
     <xsl:apply-templates/>
   </h2>
</xsl:template>

<xsl:template match="subsection/heading">
   <h3>
     <xsl:number count="chapter|section|subsection" level="multiple" format="1.1.1 "/>
     <xsl:apply-templates/>
   </h3>
</xsl:template>

<xsl:template match="subsubsection/heading">
   <h4>
     <xsl:number count="chapter|section|subsection|subsubsection" level="multiple"
                 format="1.1.1.1 "/>
     <xsl:apply-templates/>
   </h4>
</xsl:template>

<xsl:template match="paragraph/heading">
   <h4>
     <xsl:number count="chapter|section|subsection|subsubsection|paragraph"
                 level="multiple"
                 format="1.1.1.1.1 "/>
     <xsl:apply-templates/>
   </h4>
</xsl:template>

<xsl:template match="subparagraph/heading">
   <h4>
     <xsl:number count="chapter|section|subsection|subsubsection|paragraph|subparagraph"
                 level="multiple"
                 format="1.1.1.1.1.1 "/>
     <xsl:apply-templates/>
   </h4>
</xsl:template>

<!--  Trivial elements are convreted directly -->

<xsl:template match="para">
   <p>
     <xsl:apply-templates/>
   </p>
</xsl:template>

<xsl:template match="quote">
   <blockquote><p>
     <xsl:apply-templates/>
   </p></blockquote>
</xsl:template>

<xsl:template match="verbatim">
<pre>
 <xsl:apply-templates/>
</pre>
</xsl:template>

<xsl:template match="example">
<pre class='example'>
 <xsl:apply-templates/>
</pre>
</xsl:template>

<xsl:template match="itemize">
<ul>
   <xsl:apply-templates/>
</ul>
</xsl:template>

<xsl:template match="enumerate">
<ol>
   <xsl:apply-templates/>
</ol>
</xsl:template>

<xsl:template match="description">
<dl>
   <xsl:apply-templates/>
</dl>
</xsl:template>

<xsl:template match="itemize/item">
<li>
   <xsl:apply-templates/>
</li>
</xsl:template>

<xsl:template match="enumerate/item">
<li>
   <xsl:apply-templates/>
</li>
</xsl:template>

<xsl:template match="description/item">
<dt><xsl:value-of select='@tag'/></dt>
<dd>
   <xsl:apply-templates/>
</dd>
</xsl:template>

<xsl:template match="footnote">
<sup><a>
  <xsl:attribute name='href'>#footnote<xsl:number level='any'/></xsl:attribute>
  <xsl:number level='any'/>
</a></sup>
</xsl:template>

<xsl:template match="footnote" mode="footnotes">
<p>
<sup><a><xsl:attribute name='id'>footnote<xsl:number level='any'/></xsl:attribute>
        <xsl:number level='any'/></a></sup> <xsl:apply-templates/>
</p>
</xsl:template>

<xsl:template match="emph">
<em><xsl:apply-templates/></em>
</xsl:template>

<xsl:template match="strong">
<strong><xsl:apply-templates/></strong>
</xsl:template>

<xsl:template match="code">
<code><xsl:apply-templates/></code>
</xsl:template>

<xsl:template match="remark">
<span><xsl:attribute name="class">remark</xsl:attribute><xsl:apply-templates/></span>
</xsl:template>

<xsl:template match="sub">
<sub><xsl:apply-templates/></sub>
</xsl:template>

<xsl:template match="sup">
<sup><xsl:apply-templates/></sup>
</xsl:template>

<xsl:template match="color">
<span><xsl:attribute name="class"><xsl:value-of select="@colorname"/></xsl:attribute><xsl:apply-templates/></span>
</xsl:template>

<xsl:template match="big">
<big><xsl:apply-templates/></big>
</xsl:template>

<xsl:template match="small">
<small><xsl:apply-templates/></small>
</xsl:template>

<xsl:template match="table">
<table>
<xsl:apply-templates/>
</table>
</xsl:template>

<xsl:template match="newline"><br/></xsl:template>

<xsl:template match="row">
<tr><xsl:apply-templates/></tr>
</xsl:template>

<xsl:template match="thead">
<tr><xsl:apply-templates/></tr>
</xsl:template>

<xsl:template match="thead/col">
<th><xsl:apply-templates/></th>
</xsl:template>

<xsl:template match="row/col">
<td><xsl:apply-templates/></td>
</xsl:template>

<xsl:template match="picture">
   <img><xsl:attribute name="src"><xsl:value-of select="@src"/></xsl:attribute>
   </img>
</xsl:template>

<xsl:template match="label">
   <a><xsl:attribute name='id'>
      <xsl:value-of select="@name"/>
   </xsl:attribute></a>
</xsl:template>

<xsl:template match="index"></xsl:template>

<xsl:template match="ref">
   <a><xsl:attribute name='href'>#<xsl:value-of select="@to"/></xsl:attribute>
     <xsl:apply-templates/>
     <!--<xsl:apply-templates select="id(@to)" mode="section-number"/>-->
   </a>
</xsl:template>

<xsl:template match="page"></xsl:template>

<xsl:template match="reference">
<a>
<xsl:attribute name="href">
<xsl:value-of select="@href"/>
</xsl:attribute>
<xsl:apply-templates/>
</a>
</xsl:template>

<xsl:template match="math">
<xsl:element name="math" namespace="http://www.w3.org/1998/Math/MathML">
   <xsl:copy-of select='./*'/>
</xsl:element>
</xsl:template>

<xsl:template match="svg">
<xsl:if test='@src'>
   <xsl:copy-of select="document(@src)"/>
</xsl:if>
<xsl:if test='not(@src)'>
   <xsl:element name="svg" namespace="http://www.w3.org/2000/svg">
      <xsl:copy-of select='./*'/>
   </xsl:element>
</xsl:if>
</xsl:template>



</xsl:stylesheet>
