<?xml version="1.0"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/TR/xhtml1/strict">

<xsl:strip-space elements="doc chapter section"/>
<xsl:output method="text" indent="yes" encoding="iso-8859-1"/>

<xsl:template match="article">
\documentclass[a4paper]{article}
\usepackage{xcolor}
\usepackage{graphics}
\usepackage{latexsym}
\usepackage{marvosym}
\begin{document}
   <xsl:apply-templates/>
\end{document}
</xsl:template>

<xsl:template match="book">
\documentclass[a4paper]{book}
\usepackage{xcolor}
\usepackage{graphics}
\usepackage{latexsym}
\usepackage{marvosym}
\begin{document}
   <xsl:apply-templates/>
\end{document}
</xsl:template>

<xsl:template match="report">
\documentclass[a4paper]{report}
\usepackage{xcolor}
\usepackage{graphics}
\usepackage{latexsym}
\usepackage{marvosym}
\begin{document}
   <xsl:apply-templates/>
\end{document}
</xsl:template>

<xsl:template match="titlepage">
   \begin{titlepage}
   <xsl:apply-templates/>
   \end{titlepage}
</xsl:template>

<xsl:template match="title">
   \begin{center}
   \sffamily\bfseries\LARGE{<xsl:apply-templates/>}
   \end{center}
</xsl:template>

<xsl:template match="subtitle">
   \begin{center}
   \sffamily\bfseries\Large{<xsl:apply-templates/>}
   \end{center}
</xsl:template>

<xsl:template match="author">
   \begin{center}
   \sffamily{<xsl:apply-templates/>}
   \end{center}
</xsl:template>

<xsl:template match="date">
   \begin{center}
   \sffamily{<xsl:apply-templates/>}
   \end{center}
</xsl:template>

<xsl:template match="docinfo">
   \begin{tabular}{|l|l|}
   \hline
   \multicolumn{2}{|c|}{\textbf{Document Information}} \\
   \hline
   <xsl:apply-templates/>
   \end{tabular}
</xsl:template>

<xsl:template match="infoitem">
     <xsl:value-of select="@label"/> &amp;
     <xsl:apply-templates/> \\
     \hline
</xsl:template>

<xsl:template match="abstract">
   
   \vspace{0.5cm}
   \begin{bfseries}Abstract:\end{bfseries}

   \begin{quote}
   <xsl:apply-templates/>
   \end{quote}
</xsl:template>

<xsl:template match="toc">
\tableofcontents
\newpage
</xsl:template>

<xsl:template match="chapter/heading">
   \chapter{<xsl:apply-templates/>}
</xsl:template>

<xsl:template match="section/heading">
   \section{<xsl:apply-templates/>}
</xsl:template>

<xsl:template match="subsection/heading">
   \subsection{<xsl:apply-templates/>}
</xsl:template>

<xsl:template match="subsubsection/heading">
   \subsubsection{<xsl:apply-templates/>}
</xsl:template>

<xsl:template match="paragraph/heading">
   \paragraph{<xsl:apply-templates/>}
</xsl:template>

<xsl:template match="subparagraph/heading">
   \subparagraph{<xsl:apply-templates/>}
</xsl:template>

<xsl:template match="para">
   
     <xsl:apply-templates/>
</xsl:template>

<xsl:template match="quote">
\begin{quote} 
     <xsl:apply-templates/>
\end{quote}
</xsl:template>

<xsl:template match="verbatim">
\begin{verbatim} 
     <xsl:apply-templates/>
\end{verbatim}
</xsl:template>

<xsl:template match="example">
\begin{verbatim} 
 <xsl:apply-templates/>
\end{verbatim}
</xsl:template>

<xsl:template match="itemize">
\begin{itemize}
   <xsl:apply-templates/>
\end{itemize}
</xsl:template>

<xsl:template match="enumerate">
\begin{enumerate}
   <xsl:apply-templates/>
\end{enumerate}
</xsl:template>

<xsl:template match="description">
\begin{description}
   <xsl:apply-templates/>
\end{description}
</xsl:template>

<xsl:template match="itemize/item">
\item <xsl:apply-templates/>
</xsl:template>

<xsl:template match="enumerate/item">
\item <xsl:apply-templates/>
</xsl:template>

<xsl:template match="description/item">
\item[<xsl:value-of select='@tag'/>] <xsl:apply-templates/>
</xsl:template>

<xsl:template match="footnote">\footnote{<xsl:apply-templates/>}</xsl:template>

<xsl:template match="emph">\begin{itshape}<xsl:apply-templates/>\end{itshape}</xsl:template>

<xsl:template match="strong">\begin{bfseries}<xsl:apply-templates/>\end{bfseries}</xsl:template>

<xsl:template match="code">\begin{ttfamily}<xsl:apply-templates/>\end{ttfamily}</xsl:template>

<xsl:template match="remark">\begin{slshape}<xsl:apply-templates/>\end{slshape}</xsl:template>

<xsl:template match="sub">$_{<xsl:apply-templates/>}$</xsl:template>
<xsl:template match="sup">$^{<xsl:apply-templates/>}$</xsl:template>

<xsl:template match="color">\textcolor{<xsl:value-of select="@colorname"/>}{<xsl:apply-templates/>}</xsl:template>

<xsl:template match="big">\large{<xsl:apply-templates/>}</xsl:template>
<xsl:template match="small">\small{<xsl:apply-templates/>}</xsl:template>

<xsl:template match="newline">\\</xsl:template>
<xsl:template match="newpage">\newpage</xsl:template>

<xsl:template match="table">
\begin{tabular}{<xsl:value-of select="@cpos"/>c}
<xsl:apply-templates/>
\end{tabular}
</xsl:template>

<xsl:template match="thead">
<xsl:apply-templates/>\\
</xsl:template>

<xsl:template match="thead/col">
\begin{bfseries}<xsl:apply-templates/>\end{bfseries}&amp;
</xsl:template>

<xsl:template match="row">
<xsl:apply-templates/>\\
</xsl:template>

<xsl:template match="row/col">
<xsl:apply-templates/>&amp;
</xsl:template>

<xsl:template match="picture">
\scalebox{<xsl:value-of select="@scale"/>}{\includegraphics{<xsl:value-of select="@eps"/>}}
</xsl:template>

<xsl:template match="label">\label{<xsl:value-of select="@name"/>}</xsl:template>

<xsl:template match="index"></xsl:template>
<xsl:template match="ref"><xsl:apply-templates/>\ref{<xsl:value-of select="@to"/>}</xsl:template>
<xsl:template match="page"><xsl:apply-templates/>\pageref{<xsl:value-of select="@to"/>}</xsl:template>
<xsl:template match="reference">
<xsl:apply-templates/>[<xsl:value-of select="@href"/>]
</xsl:template>

<xsl:template match="include">
   <xsl:apply-templates select="document(@href)"/>
</xsl:template>

<xsl:template match="LaTeX">
 <xsl:value-of select="@command"/>
</xsl:template>
</xsl:stylesheet>

